==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/all_61.js <==
var searchData=
[
  ['a',['a',['../structplplot_1_1__N9.html#ae8a6f4039729e0f6e14795af6b4c2558',1,'plplot::_N9::a()'],['../structplplot_1_1__N10.html#af4b12ee773af19b3cb112f5730fa3826',1,'plplot::_N10::a()'],['../structPLColor.html#a3b4240c54ca0894e627d2b1c794272b1',1,'PLColor::a()'],['../structPLControlPt.html#a73722ef982c3ef58c19c9de1837d7295',1,'PLControlPt::a()'],['../structarc__struct.html#ab54aa54947964a3f511bd81b6004b4fe',1,'arc_struct::a()']]],
  ['abort_5fhandler',['abort_handler',['../plctrl_8c.html#aeb7d8fee48b1b0845b83cfa600a43438',1,'plctrl.c']]],
  ['abs',['ABS',['../plplotP_8h.html#ae2f08dc603ae93c402abd918ba4e23e1',1,'plplotP.h']]],
  ['acc',['acc',['../structPLStrip.html#acfed845c67232fe817b17cc05e22f4e0',1,'PLStrip']]],
  ['active_5fplot',['active_plot',['../structPlPlotter.html#a6d189ffe4f40ce36914934805550bbf4',1,'PlPlotter']]],
  ['active_5fstreams',['active_streams',['../classplstream.html#a40c5a40e609b74ef8b1046da85edf495',1,'plstream']]],
  ['activestate',['ActiveState',['../plplotter_8c.html#aa1f3f2a24a744225a06bdfbb13c6764f',1,'plplotter.c']]],
  ['adapter',['adapter',['../aqt_8c.html#a038483d5fc0a9a6512f765134f8f673e',1,'aqt.c']]],
  ['add',['add',['../structplf2ops__t.html#a3044489613ce51fb127a470667d7a7c0',1,'plf2ops_t']]],
  ['addcoord',['addcoord',['../plfill_8c.html#aa13a4d397cdfb55d694f502e6276f663',1,'plfill.c']]],
  ['addframe',['AddFrame',['../classwxPLplotApp.html#a3e8e60fac4a602d74df8c62feda9fe8e',1,'wxPLplotApp']]],
  ['addtoclipregion',['AddtoClipRegion',['../classwxPLDevBase.html#a321df768f5cd7c0e14bf5a774dca6340',1,'wxPLDevBase']]],
  ['adopted_5fto_5fsubpage_5fx',['adopted_to_subpage_x',['../pllegend_8c.html#acb4feedd1b2c40619e9989d1b814973a',1,'pllegend.c']]],
  ['adopted_5fto_5fsubpage_5fy',['adopted_to_subpage_y',['../pllegend_8c.html#ae1dc733fdff86908ccd342ec5726eda3',1,'pllegend.c']]],
  ['adv',['adv',['../classplstream.html#ab7f5e5c91c441fc52d4e19289780a2b2',1,'plstream::adv()'],['../classplplot_1_1core_1_1PLStream.html#a2c4bf70b9209691f579bf4b7a9b25c92',1,'plplot.core.PLStream.adv()']]],
  ['advance',['advance',['../classwxPLplotApp.html#ac66c9cf51c794e6e142703aa1cfb3eba',1,'wxPLplotApp::advance()'],['../metadefs_8h.html#ad4425e8f14c95d8eef966542aa90763b',1,'ADVANCE():&#160;metadefs.h']]],
  ['affine',['affine',['../struct__PlplotCanvasHacktextPriv.html#a73093e4fae830bd97053b1a490cfd27d',1,'_PlplotCanvasHacktextPriv']]],
  ['alarm',['alarm',['../structPLStream.html#ae101c904156d069f592ae556c4ae5229',1,'PLStream']]],
  ['alen',['Alen',['../plplotjavacJAVA__wrap_8c.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplotjavacJAVA_wrap.c'],['../plplotluacLUA__wrap_8c.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplotcmodulePYTHON_wrap.c']]],
  ['alloc2d',['alloc2d',['../csa_8c.html#afecb8e7c2408bf2e4d8a7819ca5449e2',1,'csa.c']]],
  ['alloc2dgrid',['Alloc2dGrid',['../classplplot.html#ae7e2909e2bcc51a61a0c0259ec330876',1,'plplot::Alloc2dGrid()'],['../classplstream.html#aa5552169469a3f9cc841311b13272992',1,'plstream::Alloc2dGrid()'],['../plplot__octave_8h.html#a46338ba6d12f1f040c6d03fe64050eb1',1,'Alloc2dGrid():&#160;plplot_octave.h']]],
  ['alloc_5flevel',['alloc_level',['../plcont_8c.html#a1c7f6939737f57ed1e5279c5cf7fd07c',1,'plcont.c']]],
  ['alloc_5fline',['alloc_line',['../plcont_8c.html#acfcf6b643b077801bb5a1b5529ce224d',1,'plcont.c']]],
  ['allow_5fresize',['allow_resize',['../structGcwPLdev.html#a0d134edb4cca8bd64fc9ff886f2c8290',1,'GcwPLdev']]],
  ['already_5fwarned',['already_warned',['../cairo_8c.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;cairo.c'],['../qt_8cpp.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;qt.cpp'],['../svg_8c.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;svg.c']]],
  ['alt_5fhue_5fpath',['alt_hue_path',['../structplplot_1_1__N10.html#a0ce401d3c749e8ae33652a565a59a5a8',1,'plplot::_N10::alt_hue_path()'],['../structPLControlPt.html#ac2decdd07fee85171291fa766a92f236',1,'PLControlPt::alt_hue_path()']]],
  ['alt_5funicode',['alt_unicode',['../structPLStream.html#ad5b11c7d0725f7b465356a1230111389',1,'PLStream']]],
  ['always_5fstatic',['always_static',['../classoctave__swig__type.html#af01414750456e4ce55fd24643508fddf',1,'octave_swig_type']]],
  ['angle1',['angle1',['../structarc__struct.html#ab5835c9f068a76419d1a35396ed575d3',1,'arc_struct']]],
  ['angle2',['angle2',['../structarc__struct.html#a239e57f45d87b43b53584fff68d9d995',1,'arc_struct']]],
  ['appcounter',['appCounter',['../qt_8cpp.html#ac07b45044ec40360f7ccf5d721906c19',1,'qt.cpp']]],
  ['append_5fcmdlist',['Append_Cmdlist',['../tclAPI_8c.html#ac48c3efba7bcd2380c847607918537db',1,'tclAPI.c']]],
  ['appinit',['AppInit',['../pltcl_8c.html#a7b665803780f12d53cbccad6dbcfc689',1,'AppInit(Tcl_Interp *interp):&#160;pltcl.c'],['../plserver_8c.html#a7b665803780f12d53cbccad6dbcfc689',1,'AppInit(Tcl_Interp *interp):&#160;plserver.c']]],
  ['aqt_2ec',['aqt.c',['../aqt_8c.html',1,'']]],
  ['aqt_5fdefault_5fx',['AQT_Default_X',['../aqt_8c.html#aa3bd481b3ea846efcb485296dd45ffcb',1,'aqt.c']]],
  ['aqt_5fdefault_5fy',['AQT_Default_Y',['../aqt_8c.html#a6c03281d1df0bfc075d855692c576978',1,'aqt.c']]],
  ['aqt_5ffont_5fenv_5fnames',['aqt_font_env_names',['../aqt_8c.html#ac9e0702fe235f0af1382c7fbaa0bdb09',1,'aqt.c']]],
  ['aqt_5ffontlookup',['AQT_FontLookup',['../aqt_8c.html#a6fb8ee7352b3d90ad5863a6aa109a3cd',1,'aqt.c']]],
  ['aqt_5fn_5ffontlookup',['AQT_N_FontLookup',['../aqt_8c.html#a7d7747b9873844ee783d292524c0b64d',1,'aqt.c']]],
  ['arc',['arc',['../classplstream.html#a2df216bc3bcfb93557a580f9db97d31c',1,'plstream::arc()'],['../classplplot_1_1core_1_1PLStream.html#a4eec09856b551b3e7f060ba97b5c045f',1,'plplot.core.PLStream.arc()'],['../cairo_8c.html#aed9756e3af7c349312e9663cc0f94d30',1,'arc():&#160;cairo.c']]],
  ['arc_5fstruct',['arc_struct',['../structarc__struct.html',1,'']]],
  ['argc',['argc',['../qt_8cpp.html#ad1447518f4372828b8435ae82e48499e',1,'qt.cpp']]],
  ['argtable',['argTable',['../plserver_8c.html#aa2d7de8127fc5e1205be8243215a5aef',1,'argTable():&#160;plserver.c'],['../tkMain_8c.html#aa2d7de8127fc5e1205be8243215a5aef',1,'argTable():&#160;tkMain.c']]],
  ['argv',['argv',['../qt_8cpp.html#af2efa898e9eed6fe6715279cb1ec35b0',1,'qt.cpp']]],
  ['argv_5fto_5fchars',['argv_to_chars',['../tclAPI_8c.html#a465b6793aabf98ab5a98a2c6ee731cc3',1,'tclAPI.c']]],
  ['argv_5fto_5fdoubles',['argv_to_doubles',['../tclAPI_8c.html#a745a6beb32ab13d604771663d1d2179a',1,'tclAPI.c']]],
  ['argv_5fto_5fints',['argv_to_ints',['../tclAPI_8c.html#a623e8233b572bc4f359b041a18ea93ae',1,'tclAPI.c']]],
  ['arpool',['arpool',['../aqt_8c.html#a62288d128ffc307d0f661546ec48d199',1,'aqt.c']]],
  ['arrow_5ffill',['arrow_fill',['../structPLStream.html#a7ac1e3c7c8a4bafc756c2eda23a3e294',1,'PLStream']]],
  ['arrow_5fnpts',['arrow_npts',['../structPLStream.html#acdc0f21ca7d4639067884e64a7f56fae',1,'PLStream']]],
  ['arrow_5fx',['arrow_x',['../structPLStream.html#a015dd508317467f440062b7e1bdddb24',1,'PLStream']]],
  ['arrow_5fy',['arrow_y',['../structPLStream.html#ac334ee79d7d35de4e9298bfea47db84c',1,'PLStream']]],
  ['art_5fdrect_5fhacktext',['art_drect_hacktext',['../plplotcanvas-hacktext_8c.html#ac4f986ee6129bf458b5ea277579be5ef',1,'plplotcanvas-hacktext.c']]],
  ['as_5fbuffer',['as_buffer',['../structPyHeapTypeObject.html#a026c64b0a5163ea580e79640ecf209de',1,'PyHeapTypeObject']]],
  ['as_5fmapping',['as_mapping',['../structPyHeapTypeObject.html#a3112d193aea288a92036360bec1ce0a5',1,'PyHeapTypeObject']]],
  ['as_5fnumber',['as_number',['../structPyHeapTypeObject.html#a795de378df40d11321c0dbe463759560',1,'PyHeapTypeObject']]],
  ['as_5fsequence',['as_sequence',['../structPyHeapTypeObject.html#ad553caad5da3a7004aae1b7ac0289f12',1,'PyHeapTypeObject']]],
  ['as_5fvalue',['as_value',['../classoctave__swig__type.html#a28b6ab346ab6b2070e1f79b2b8125e32',1,'octave_swig_type']]],
  ['aspdev',['aspdev',['../structPLStream.html#aa6d6f9587b12cd4133b172a93ae9d8c1',1,'PLStream']]],
  ['aspect',['aspect',['../structPLStream.html#a79d9ed2a822851f28285913cae12b840',1,'PLStream']]],
  ['aspori',['aspori',['../structPLStream.html#a3bc2ac0e93b21ffff11aba5de71571be',1,'PLStream']]],
  ['assign',['assign',['../classoctave__swig__type.html#a79f184d20bef4691ffd0b61eceddd6cc',1,'octave_swig_type::assign(const std::string &amp;name, const octave_value &amp;ov)'],['../classoctave__swig__type.html#a432ff2f024024be845b1342e36bc7502',1,'octave_swig_type::assign(const std::string &amp;name, const swig_octave_member *m)']]],
  ['at_5fbop',['at_bop',['../structPLRDev.html#a47a7b661ad619d752cc6cf95b9b19dba',1,'PLRDev::at_bop()'],['../plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55bacef624e37a53fb2a68d5c9a08b8a7ccf',1,'AT_BOP():&#160;plcore.c']]],
  ['at_5feop',['at_eop',['../structPLRDev.html#a18b078383daba6f7399d73aa5b2a8433',1,'PLRDev::at_eop()'],['../plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55ba74ab759c0ff9e51f5df3638a75023e6d',1,'AT_EOP():&#160;plcore.c']]],
  ['attributes',['attributes',['../structswig__lua__class.html#a3061adc91d7cb1a16967927e8d4a7261',1,'swig_lua_class']]],
  ['auto_5fpath',['auto_path',['../structPLStream.html#ad2ba4001e1e8e82da00e8c6011e2bafd',1,'PLStream::auto_path()'],['../plserver_8c.html#a584c59afcabcf1d096319dbc948c4a68',1,'auto_path():&#160;plserver.c']]],
  ['axes',['axes',['../classplstream.html#aae9c3ed421ec29c56c6a1ea0767ea0d4',1,'plstream::axes()'],['../classplplot_1_1core_1_1PLStream.html#abedfa8532b2bfea1adc596e39e7be4d7',1,'plplot.core.PLStream.axes()']]],
  ['axis_5fopts',['axis_opts',['../plplot__octave_8h.html#a5afac14f343de19547bbfdbcf9ae09a9',1,'plplot_octave.h']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/all_61.js <==
var searchData=
[
  ['a',['a',['../structplplot_1_1__N9.html#ae8a6f4039729e0f6e14795af6b4c2558',1,'plplot::_N9::a()'],['../structplplot_1_1__N10.html#af4b12ee773af19b3cb112f5730fa3826',1,'plplot::_N10::a()'],['../structPLColor.html#a3b4240c54ca0894e627d2b1c794272b1',1,'PLColor::a()'],['../structPLControlPt.html#a73722ef982c3ef58c19c9de1837d7295',1,'PLControlPt::a()'],['../structarc__struct.html#ab54aa54947964a3f511bd81b6004b4fe',1,'arc_struct::a()']]],
  ['abort_5fhandler',['abort_handler',['../plctrl_8c.html#aeb7d8fee48b1b0845b83cfa600a43438',1,'plctrl.c']]],
  ['abs',['ABS',['../plplotP_8h.html#ae2f08dc603ae93c402abd918ba4e23e1',1,'plplotP.h']]],
  ['acc',['acc',['../structPLStrip.html#acfed845c67232fe817b17cc05e22f4e0',1,'PLStrip']]],
  ['access',['access',['../plfreetype_8c.html#a694e04c2c93271c787470ba441cc1d98',1,'plfreetype.c']]],
  ['active_5fplot',['active_plot',['../structPlPlotter.html#a6d189ffe4f40ce36914934805550bbf4',1,'PlPlotter']]],
  ['active_5fstreams',['active_streams',['../classplstream.html#a40c5a40e609b74ef8b1046da85edf495',1,'plstream']]],
  ['activestate',['ActiveState',['../plplotter_8c.html#aa1f3f2a24a744225a06bdfbb13c6764f',1,'plplotter.c']]],
  ['adapter',['adapter',['../aqt_8c.html#a038483d5fc0a9a6512f765134f8f673e',1,'aqt.c']]],
  ['add',['add',['../structplf2ops__t.html#a3044489613ce51fb127a470667d7a7c0',1,'plf2ops_t']]],
  ['addcoord',['addcoord',['../plfill_8c.html#aa13a4d397cdfb55d694f502e6276f663',1,'plfill.c']]],
  ['adopted_5fto_5fsubpage_5fx',['adopted_to_subpage_x',['../pllegend_8c.html#acb4feedd1b2c40619e9989d1b814973a',1,'pllegend.c']]],
  ['adopted_5fto_5fsubpage_5fy',['adopted_to_subpage_y',['../pllegend_8c.html#ae1dc733fdff86908ccd342ec5726eda3',1,'pllegend.c']]],
  ['adv',['adv',['../classplstream.html#ab7f5e5c91c441fc52d4e19289780a2b2',1,'plstream::adv()'],['../classplplot_1_1core_1_1PLStream.html#a2c4bf70b9209691f579bf4b7a9b25c92',1,'plplot.core.PLStream.adv()']]],
  ['advance',['ADVANCE',['../metadefs_8h.html#ad4425e8f14c95d8eef966542aa90763b',1,'metadefs.h']]],
  ['alarm',['alarm',['../structPLStream.html#ae101c904156d069f592ae556c4ae5229',1,'PLStream']]],
  ['alen',['Alen',['../plplotjavacJAVA__wrap_8c.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplotjavacJAVA_wrap.c'],['../plplotluacLUA__wrap_8c.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplotcmodulePYTHON_wrap.c']]],
  ['alloc2d',['alloc2d',['../csa_8c.html#afecb8e7c2408bf2e4d8a7819ca5449e2',1,'csa.c']]],
  ['alloc2dgrid',['Alloc2dGrid',['../classplplot.html#ae7e2909e2bcc51a61a0c0259ec330876',1,'plplot::Alloc2dGrid()'],['../classplstream.html#aa5552169469a3f9cc841311b13272992',1,'plstream::Alloc2dGrid()']]],
  ['alloc_5flevel',['alloc_level',['../plcont_8c.html#a1c7f6939737f57ed1e5279c5cf7fd07c',1,'plcont.c']]],
  ['alloc_5fline',['alloc_line',['../plcont_8c.html#acfcf6b643b077801bb5a1b5529ce224d',1,'plcont.c']]],
  ['already_5fwarned',['already_warned',['../cairo_8c.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;cairo.c'],['../qt_8cpp.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;qt.cpp'],['../svg_8c.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;svg.c']]],
  ['alt_5fhue_5fpath',['alt_hue_path',['../structplplot_1_1__N10.html#a0ce401d3c749e8ae33652a565a59a5a8',1,'plplot::_N10::alt_hue_path()'],['../structPLControlPt.html#ac2decdd07fee85171291fa766a92f236',1,'PLControlPt::alt_hue_path()']]],
  ['alt_5funicode',['alt_unicode',['../structPLStream.html#ad5b11c7d0725f7b465356a1230111389',1,'PLStream']]],
  ['alternate_5funicode_5fprocessing',['alternate_unicode_processing',['../plcore_8c.html#a684791a3ca4a8011f221eeb3d36181f2',1,'plcore.c']]],
  ['always_5fstatic',['always_static',['../classoctave__swig__type.html#af01414750456e4ce55fd24643508fddf',1,'octave_swig_type']]],
  ['angle1',['angle1',['../structarc__struct.html#ab5835c9f068a76419d1a35396ed575d3',1,'arc_struct']]],
  ['angle2',['angle2',['../structarc__struct.html#a239e57f45d87b43b53584fff68d9d995',1,'arc_struct']]],
  ['appcounter',['appCounter',['../qt_8cpp.html#ac07b45044ec40360f7ccf5d721906c19',1,'qt.cpp']]],
  ['appendbuffer',['AppendBuffer',['../classwxPLplotstream.html#a69f96936f5c904e0b1452f118a152200',1,'wxPLplotstream']]],
  ['appendflt',['appendflt',['../plmap_8c.html#aed1a69ce9638d5330956c10d9165b3e7',1,'plmap.c']]],
  ['appendfltptr',['appendfltptr',['../plmap_8c.html#a81beb14e5b4371ad18b8ea3e8a86c654',1,'plmap.c']]],
  ['appendint',['appendint',['../plmap_8c.html#a6c1100974f916b51c213b9b27fd6879f',1,'plmap.c']]],
  ['appinit',['AppInit',['../pltcl_8c.html#a7b665803780f12d53cbccad6dbcfc689',1,'AppInit(Tcl_Interp *interp):&#160;pltcl.c'],['../plserver_8c.html#a7b665803780f12d53cbccad6dbcfc689',1,'AppInit(Tcl_Interp *interp):&#160;plserver.c']]],
  ['aqt_2ec',['aqt.c',['../aqt_8c.html',1,'']]],
  ['aqt_5fdefault_5fx',['AQT_Default_X',['../aqt_8c.html#aa3bd481b3ea846efcb485296dd45ffcb',1,'aqt.c']]],
  ['aqt_5fdefault_5fy',['AQT_Default_Y',['../aqt_8c.html#a6c03281d1df0bfc075d855692c576978',1,'aqt.c']]],
  ['aqt_5ffont_5fenv_5fnames',['aqt_font_env_names',['../aqt_8c.html#ac9e0702fe235f0af1382c7fbaa0bdb09',1,'aqt.c']]],
  ['aqt_5ffontlookup',['AQT_FontLookup',['../aqt_8c.html#a6fb8ee7352b3d90ad5863a6aa109a3cd',1,'aqt.c']]],
  ['aqt_5fn_5ffontlookup',['AQT_N_FontLookup',['../aqt_8c.html#a7d7747b9873844ee783d292524c0b64d',1,'aqt.c']]],
  ['aquire',['aquire',['../classPLNamedMutex.html#a8498a3e3bbf6e2905fa7b936f8a03eb8',1,'PLNamedMutex::aquire()'],['../classPLNamedMutex.html#a3cdaca8dab31100d2a660cdc392f5d7b',1,'PLNamedMutex::aquire(unsigned long millisecs)']]],
  ['aquirenowait',['aquireNoWait',['../classPLNamedMutex.html#a283bb66e2a98324a5e070f2df3d8c4e4',1,'PLNamedMutex']]],
  ['arc',['arc',['../classplstream.html#a2df216bc3bcfb93557a580f9db97d31c',1,'plstream::arc()'],['../classplplot_1_1core_1_1PLStream.html#a4eec09856b551b3e7f060ba97b5c045f',1,'plplot.core.PLStream.arc()'],['../cairo_8c.html#aed9756e3af7c349312e9663cc0f94d30',1,'arc():&#160;cairo.c']]],
  ['arc_5fstruct',['arc_struct',['../structarc__struct.html',1,'']]],
  ['argc',['argc',['../qt_8cpp.html#ad1447518f4372828b8435ae82e48499e',1,'qt.cpp']]],
  ['argtable',['argTable',['../plserver_8c.html#aa2d7de8127fc5e1205be8243215a5aef',1,'argTable():&#160;plserver.c'],['../tkMain_8c.html#aa2d7de8127fc5e1205be8243215a5aef',1,'argTable():&#160;tkMain.c']]],
  ['argv',['argv',['../qt_8cpp.html#af2efa898e9eed6fe6715279cb1ec35b0',1,'qt.cpp']]],
  ['argv_5fto_5fchars',['argv_to_chars',['../tclAPI_8c.html#a465b6793aabf98ab5a98a2c6ee731cc3',1,'tclAPI.c']]],
  ['argv_5fto_5fdoubles',['argv_to_doubles',['../tclAPI_8c.html#a745a6beb32ab13d604771663d1d2179a',1,'tclAPI.c']]],
  ['argv_5fto_5fints',['argv_to_ints',['../tclAPI_8c.html#a623e8233b572bc4f359b041a18ea93ae',1,'tclAPI.c']]],
  ['arpool',['arpool',['../aqt_8c.html#a62288d128ffc307d0f661546ec48d199',1,'aqt.c']]],
  ['arrow_5ffill',['arrow_fill',['../structPLStream.html#a7ac1e3c7c8a4bafc756c2eda23a3e294',1,'PLStream']]],
  ['arrow_5fnpts',['arrow_npts',['../structPLStream.html#acdc0f21ca7d4639067884e64a7f56fae',1,'PLStream']]],
  ['arrow_5fx',['arrow_x',['../structPLStream.html#a015dd508317467f440062b7e1bdddb24',1,'PLStream']]],
  ['arrow_5fy',['arrow_y',['../structPLStream.html#ac334ee79d7d35de4e9298bfea47db84c',1,'PLStream']]],
  ['as_5fbuffer',['as_buffer',['../structPyHeapTypeObject.html#a026c64b0a5163ea580e79640ecf209de',1,'PyHeapTypeObject']]],
  ['as_5fmapping',['as_mapping',['../structPyHeapTypeObject.html#a3112d193aea288a92036360bec1ce0a5',1,'PyHeapTypeObject']]],
  ['as_5fnumber',['as_number',['../structPyHeapTypeObject.html#a795de378df40d11321c0dbe463759560',1,'PyHeapTypeObject']]],
  ['as_5fsequence',['as_sequence',['../structPyHeapTypeObject.html#ad553caad5da3a7004aae1b7ac0289f12',1,'PyHeapTypeObject']]],
  ['as_5fvalue',['as_value',['../classoctave__swig__type.html#a28b6ab346ab6b2070e1f79b2b8125e32',1,'octave_swig_type']]],
  ['aspdev',['aspdev',['../structPLStream.html#aa6d6f9587b12cd4133b172a93ae9d8c1',1,'PLStream']]],
  ['aspect',['aspect',['../structPLStream.html#a79d9ed2a822851f28285913cae12b840',1,'PLStream']]],
  ['aspori',['aspori',['../structPLStream.html#a3bc2ac0e93b21ffff11aba5de71571be',1,'PLStream']]],
  ['assign',['assign',['../classoctave__swig__type.html#a79f184d20bef4691ffd0b61eceddd6cc',1,'octave_swig_type::assign(const std::string &amp;name, const octave_value &amp;ov)'],['../classoctave__swig__type.html#a432ff2f024024be845b1342e36bc7502',1,'octave_swig_type::assign(const std::string &amp;name, const swig_octave_member *m)']]],
  ['at_5fbop',['at_bop',['../structPLRDev.html#a47a7b661ad619d752cc6cf95b9b19dba',1,'PLRDev::at_bop()'],['../plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55bacef624e37a53fb2a68d5c9a08b8a7ccf',1,'AT_BOP():&#160;plcore.c']]],
  ['at_5feop',['at_eop',['../structPLRDev.html#a18b078383daba6f7399d73aa5b2a8433',1,'PLRDev::at_eop()'],['../plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55ba74ab759c0ff9e51f5df3638a75023e6d',1,'AT_EOP():&#160;plcore.c']]],
  ['attributes',['attributes',['../structswig__lua__class.html#a3061adc91d7cb1a16967927e8d4a7261',1,'swig_lua_class']]],
  ['auto_5fpath',['auto_path',['../structPLStream.html#ad2ba4001e1e8e82da00e8c6011e2bafd',1,'PLStream::auto_path()'],['../plserver_8c.html#a584c59afcabcf1d096319dbc948c4a68',1,'auto_path():&#160;plserver.c']]],
  ['axes',['axes',['../classplstream.html#aae9c3ed421ec29c56c6a1ea0767ea0d4',1,'plstream::axes()'],['../classplplot_1_1core_1_1PLStream.html#abedfa8532b2bfea1adc596e39e7be4d7',1,'plplot.core.PLStream.axes()']]]
];
